#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ap-normalize
version:              0.1.0.1
visibility:           public
id:                   ap-normalize-0.1.0.1-6Z6VBwZ59hMB7oPb9nKOuv
key:                  ap-normalize-0.1.0.1-6Z6VBwZ59hMB7oPb9nKOuv
license:              MIT
copyright:            Li-yao Xia 2020
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
synopsis:             Self-normalizing applicative expressions
description:
    An applicative functor transformer to normalize expressions using @(\<$>)@,
    @(\<*>)@, and @pure@ into a linear list of actions.
    See "ApNormalize" to get started.

category:             Control
abi:                  eb95c066f3d3bd63e4b1695993df6277
exposed:              True
exposed-modules:      ApNormalize ApNormalize.Aps ApNormalize.DList
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ap-normalize-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ap-normalize-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ap-normalize-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ap-normalize
hs-libraries:         HSap-normalize-0.1.0.1-6Z6VBwZ59hMB7oPb9nKOuv
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-ap-normalize/html/ap-normalize.haddock

haddock-html:         /usr/share/doc/haskell-ap-normalize/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

